==> guymager_0.5.9.orig.tar.gz: guymager-0.5.9/threadhash.h <==
// ****************************************************************************
//  Project:        GUYMAGER
// ****************************************************************************
//  Programmer:     Guy Voncken
//                  Police Grand-Ducale
//                  Service de Police Judiciaire
//                  Section Nouvelles Technologies
// ****************************************************************************
//  Module:         Thread for calculating hashes
// ****************************************************************************

// Copyright 2008, 2009, 2010 Guy Voncken
//
// This file is part of guymager.
//
// guymager is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
//
// guymager is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with guymager. If not, see <http://www.gnu.org/licenses/>.

#ifndef __THREADHASH_H__
#define __THREADHASH_H__

#include <QThread>   //lint !e537 Repeated include

#ifndef __DEVICE_H__
  #include "device.h"
#endif

class t_ThreadHashLocal;

class t_ThreadHash: public QThread
{
   Q_OBJECT

   public:
      t_ThreadHash ();
      t_ThreadHash (t_pDevice pDevice);
     ~t_ThreadHash ();

   protected:
      void run (void);

   signals:
      void SignalEnded (t_pDevice pDevice);

   private slots:
      void SlotFinished (void);

   private:
      t_ThreadHashLocal *pOwn;
};

// ------------------------------------
//             Error codes
// ------------------------------------

enum
{
   ERROR_THREADHASH_CONSTRUCTOR_NOT_SUPPORTED = ERROR_BASE_THREADHASH + 1,
   ERROR_THREADHASH_LIBEWF_FAILED
};

#endif

==> guymager_0.6.5.orig.tar.gz: guymager-0.6.5/threadhash.h <==
// ****************************************************************************
//  Project:        GUYMAGER
// ****************************************************************************
//  Programmer:     Guy Voncken
//                  Police Grand-Ducale
//                  Service de Police Judiciaire
//                  Section Nouvelles Technologies
// ****************************************************************************
//  Module:         Thread for calculating hashes
// ****************************************************************************

// Copyright 2008, 2009, 2010, 2011 Guy Voncken
//
// This file is part of guymager.
//
// guymager is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
//
// guymager is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with guymager. If not, see <http://www.gnu.org/licenses/>.

#ifndef __THREADHASH_H__
#define __THREADHASH_H__

#include "thread.h"

#ifndef __DEVICE_H__
  #include "device.h"
#endif

class t_ThreadHashLocal;

class t_ThreadHash: public t_Thread
{
   Q_OBJECT

   public:
      t_ThreadHash ();
      t_ThreadHash (t_pDevice pDevice);
     ~t_ThreadHash ();

   protected:
      void run (void);

   signals:
      void SignalEnded (t_pDevice pDevice);

   private slots:
      void SlotFinished (void);

   private:
      t_ThreadHashLocal *pOwn;
};

// ------------------------------------
//             Error codes
// ------------------------------------

enum
{
   ERROR_THREADHASH_CONSTRUCTOR_NOT_SUPPORTED = ERROR_BASE_THREADHASH + 1,
   ERROR_THREADHASH_LIBEWF_FAILED
};

#endif
